@@ -21,6 +21,7 @@ class TestQuietAssets < Minitest::Test
     @app = Class.new(Rails::Application)
     @app.config.eager_load = false
     @app.config.logger = ActiveSupport::Logger.new("/dev/null")
+    @app.config.active_support.to_time_preserves_timezone = :zone
 
     FileUtils.mkdir_p(ASSET_PATH)
     File.open(ASSET_PATH.join("manifest.js"), "w") { |f| f << "" }
@@ -43,6 +44,12 @@ class TestQuietAssets < Minitest::Test
     assert_equal Logger::DEBUG, middleware.call("PATH_INFO" => "/path/to/thing")
   end
 
+  def test_logger_does_not_respond_to_silence
+    ::Rails.logger.stub :respond_to?, false do
+      assert_raises(Sprockets::Rails::LoggerSilenceError) { middleware.call("PATH_INFO" => "/assets/stylesheets/application.css") }
+    end
+  end
+
   private
 
   def middleware
